@@ -26,6 +26,13 @@ def is_file_consistent(local_path_file, md5_hash):
     return True
 
 
+def get_parser():
+    from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
+    parser = ArgumentParser(description=__doc__,
+                            formatter_class=ArgumentDefaultsHelpFormatter)
+    return parser
+
+
 def main():
     # Read config file. This has to get updated via git
     PROJECT_ROOT = utils.get_project_root()
@@ -50,8 +57,6 @@ def main():
 
 
 if __name__ == "__main__":
-    from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
-    parser = ArgumentParser(description=__doc__,
-                            formatter_class=ArgumentDefaultsHelpFormatter)
-    args = parser.parse_args()
+    parser = get_parser()
+    parser.parse_args()
     main()
